import 'package:flutter/material.dart';
import 'package:netmera_flutter_sdk/Netmera.dart';
import 'package:netmera_flutter_sdk/NetmeraCategoryFilter.dart';
import 'package:netmera_flutter_sdk/NetmeraCategory.dart';

///
/// Copyright (c) 2019 Inomera Research.
/// Author Burak Soykal
///
class CategoryPage extends StatefulWidget {
  @override
  _CategoryPageState createState() => _CategoryPageState();
}

class _CategoryPageState extends State<CategoryPage> {
  String _currentStatus = Netmera.PUSH_OBJECT_STATUS_ALL.toString();
  List<Widget> _categories = List();
  List<NetmeraCategory> _categoryList = List();

  List<DropdownMenuItem<String>> getCategoryStatusList() {
    List<DropdownMenuItem<String>> items = new List();
    items.add(new DropdownMenuItem(value: Netmera.PUSH_OBJECT_STATUS_ALL.toString(), child: new Text("ALL")));
    items.add(new DropdownMenuItem(value: Netmera.PUSH_OBJECT_STATUS_READ.toString(), child: new Text("READ")));
    items.add(new DropdownMenuItem(value: Netmera.PUSH_OBJECT_STATUS_UNREAD.toString(), child: new Text("UNREAD")));
    items.add(new DropdownMenuItem(value: Netmera.PUSH_OBJECT_STATUS_DELETED.toString(), child: new Text("DELETED")));
    return items;
  }

  onCategoryStatusChanged(String status) {
    setState(() {
      _currentStatus = status;
    });
  }

  clearCategoryList() {
    setState(() {
      _categories.clear();
    });
  }

  String getStatusText(int status) {
    switch (status) {
      case Netmera.PUSH_OBJECT_STATUS_ALL:
        return "ALL";
        break;
      case Netmera.PUSH_OBJECT_STATUS_READ:
        return "READ";
        break;
      case Netmera.PUSH_OBJECT_STATUS_UNREAD:
        return "UNREAD";
        break;
      case Netmera.PUSH_OBJECT_STATUS_DELETED:
        return "DELETED";
        break;
    }
    return "";
  }

  fillCategoryList(list) {
    _categoryList = list;
    list.forEach((NetmeraCategory item) {
      setState(() {
        _categories.add(Text(item.getCategoryName() +" :: (Read:" + item.getReadCount().toString() + ")-(UnRead:" + item.getUnReadCount().toString() + ")-(Deleted:" + item.getDeletedCount().toString() + ")"));
      });
    });
  }

  // Click Functions
  emptyAction() {}

  getCategoryFilter() {
    NetmeraCategoryFilter categoryFilter = new NetmeraCategoryFilter();
    categoryFilter.setPageSize(2);
    categoryFilter.setStatus(int.parse(_currentStatus));
    categoryFilter.setIncludeExpiredObjects(true);
    return categoryFilter;
  }

  fetchCategory() async {
    clearCategoryList();
    Netmera.fetchCategory(getCategoryFilter()).then((list) {
      fillCategoryList(list);
    });
  }

  fetchNextCategoryPage() async {
    Netmera.fetchNextCategory().then((list) {
      if (list.isNotEmpty) {
        clearCategoryList();
      }
      fillCategoryList(list);
    });
  }

  handlePushObject() async {
    if(_categoryList.isNotEmpty) {
      Netmera.handleLastMessage(_categoryList[0]);
    }
  }

  @override
  Widget build(BuildContext context) {
    return Column(
      mainAxisAlignment: MainAxisAlignment.center,
      children: [
        Column(
          children: _categories,
        ),
        new DropdownButton(
          value: _currentStatus,
          items: getCategoryStatusList(),
          onChanged: onCategoryStatusChanged,
        ),
        RaisedButton(
          child: Text('Fetch Category'),
          onPressed: fetchCategory,
        ),
        RaisedButton(
          child: Text('Fetch Next Page'),
          onPressed: fetchNextCategoryPage,
        ),
        RaisedButton(
          child: Text('Handle Last Message'),
          onPressed: handlePushObject,
        ),
      ],
    );
  }
}
